aiscalator.airflow package
==========================

Submodules
----------

aiscalator.airflow.command module
-------------------------------------------

.. automodule:: aiscalator.airflow.command
    :members:
    :undoc-members:
    :show-inheritance:

aiscalator.airflow.cli module
-----------------------------

.. automodule:: aiscalator.airflow.cli
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: aiscalator.airflow
    :members:
    :undoc-members:
    :show-inheritance:
